#
# spec file for package gnome-maps
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-maps
Version:        3.28.2
Release:        lp150.1.1
Summary:        Maps Application for GNOME
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Apps/Maps
Source:         http://download.gnome.org/sources/gnome-maps/3.28/%{name}-%{version}.tar.xz
# Needed for typelib() Requires
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(champlain-0.12) >= 0.12.14
BuildRequires:  pkgconfig(folks) >= 0.10.0
BuildRequires:  pkgconfig(gee-0.8) >= 0.16.0
BuildRequires:  pkgconfig(geoclue-2.0) >= 0.12.99
BuildRequires:  pkgconfig(geocode-glib-1.0) >= 3.15.2
BuildRequires:  pkgconfig(gio-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gjs-1.0) >= 1.50.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.10.1
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(rest-0.7) >= 0.7.90
Recommends:     %{name}-lang
Recommends:     dbus(org.freedesktop.GeoClue2)

%description
Maps is a maps application for GNOME 3. It allows viewing street maps from
OpenStreetMaps and satellite imagery from Mapbox. You can also get directions
for your journeys, whether on foot, by bike, or by car.

%lang_package

%prep
%autosetup -p1

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file -G "Maps Application" org.gnome.Maps DesktopUtility
# There is no devel file, so at this moment also no need to keep
rm %{buildroot}%{_datadir}/gir-1.0/GnomeMaps-1.0.gir

%files
%license COPYING
%doc NEWS
%{_bindir}/%{name}
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.Maps.appdata.xml
%{_datadir}/applications/org.gnome.Maps.desktop
%{_datadir}/dbus-1/services/org.gnome.Maps.service
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/org.gnome.Maps*
%{_datadir}/glib-2.0/schemas/org.gnome.Maps.gschema.xml
%{_libdir}/%{name}/

%files lang -f %{name}.lang

%changelog
* Tue May  8 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Enable selecting map markers on touch screens.
  + Updated translations.
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Fix an accidentally untranslated string.
  + Updated translations.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Change license of two files to GPL 2 or later (as was the
    original intension and what the project as a whole is using).
  + Updated translations.
- Change license back to GPL-2.0-or-later: upstream fixed the
  issue.
* Fri Mar  9 2018 dimstar@opensuse.org
- Change license to GPL-3.0-or-later: the two files
  ./lib/maps-osm-oauth-proxy-call.[ch] pull the license from
  GPL-2.0-or-later to GPL-3.0-or-later.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Updated POI definitions for OpenStreetMap editing.
  + Fix a segmentation fault at exit.
  + Fix missing generated files and third-party licenses in the
    distributed release archive.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Use moder JS features (ES6), classes and arrow notation
    (=> () ) for binding anonymous functions.
  + Change default line with and color for layer lines in loaded
    layers to make them more visible.
  + Don't select text in place entries in the routing sidebar when
    auto-completing.
  + Bugfixes for keyboard navigation in search entry completion
    popover.
  + Add additional tooltips for buttons in the routing sidebar.
  + Decrease height of OSM login dialog.
  + Updated translations.
* Tue Jan  9 2018 dimstar@opensuse.org
- Update to version 3.27.4:
  + Show thumnails from Wikipedia in the place bubbles when
    availability.
  + Make the place bubble popovers follow the map when the view
    scrolls (i.e. when using the keyboard shortcuts to scroll).
  + Move the zoom control buttons to the headerbar to mitigate an
    issue with Clutter and overlay GTK+ widgets on Wayland.
  + Adapt libgweather dependency to use gitlab.gnome.org for
    building Flatpaks.
  + Updated translations.
* Wed Dec 27 2017 luc14n0@linuxmail.org
- Update to version 3.27.3:
  + Show tile provider and OSM attribution in the About dialog.
  + Updated translations.
- Update Url to https://wiki.gnome.org/Apps/Maps: the current Maps'
  web page location.
- Adopt the use of %%make_build macro rather than raw make command,
  following the best practices.
* Wed Dec 27 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Fix:
  - Maps to be available as an option for "Open with another
    application" for geo shape layer files.
  - JS warnings about redundant function arguments and similar
    things.
  + Updated translations.
- Drop gnome-maps-is-translations.patch and
  gnome-maps-nb-translations.patch: fixed upstream.
- Drop %%glib2_gsettings_schema_requires macro since RPM file
  triggers take care of this function now.
* Wed Dec 27 2017 badshah400@gmail.com
- Update to version 3.27.1:
  + Use sidebar icon style for icons in the routing results.
  + Improve the look of route labels for public transit trips when
    using the dark theme.
  + Add --version command line option.
  + Fix network detection when running as a Flatpak.
  + Update appdata screenshots.
  + Show stored routes according to locale direction.
* Fri Dec 22 2017 zaitor@opensuse.org
- Add gnome-maps-is-translations.patch: Update Icelandic
  translations.
- Add gnome-maps-nb-translations.patch: Update Norwegian Bokmål
  translations.
- Clean up spec, use modern macros.
- Add lang package Recommends.
* Wed Nov  1 2017 dimstar@opensuse.org
- Update to version 3.26.2:
  + Fix network detection when running as a Flatpak.
  + Updated translations.
* Wed Oct  4 2017 zaitor@opensuse.org
- Update to version 3.26.1:
  + Avoid a GTK+ warning on startup.
  + Export symbols from modules using var instead of const to
    comply with ES6 and avoid a warning on newer GJS versions.
  + Updated translations.
* Tue Oct  3 2017 jengelh@inai.de
- Update RPM groups.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Don't focus the search entry on start (prevents showing the
    on-screen keyboard at start on touch devices).
  + Make OSM edit and export image dialogs modal (fixes positioning
    on Wayland).
  + Update OSM POI definitions and translations.
  + Updated translations.
* Mon Aug 21 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Fix loading layer files when running as Flatpak.
  + Don't allow adding more than one instance of address on OSM
    objects.
  + Updated translations.
* Mon Aug  7 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Allow viewing and editing OSM editor notes when editing
    objects.
  + Updated translations.
* Thu Jul 20 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Show feedback when no search results were found.
  + Update Flatpak manifest for build changes in geocode-glib.
  + Various bugfixes.
  + Updated translations.
- Drop no longer needed glib2_gsettings_schema_post(un),
  icon_theme_cache_post(un) and desktop_database_post(un) from
  post(un) handling, we have file-triggers to take care of this for
  us now.
* Tue Jun 20 2017 dimstar@opensuse.org
- Update to version 3.25.3:
  + Added keyboard shortcuts for switching between street and
    aerial view.
  + Added keyboard shortcut for opening layer files.
  + Remember the last used mode of transportation for routing (also
    now default to walking on first run).
  + For transit results, don't reset previous list when no later or
    earlier alternatives are found.
  + Also print coordinates in debug printout from GeoClue.
  + Show and support editing for additional OpenStreetMap tags
    (religion and information on availability of toilets).
  + Updated translations.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Fix OpenStreetMap editing in Flatpaks (update librest build
    dependency).
  + Use localized format when showing distances.
  + Updated translations.
* Tue May 23 2017 firebird209@gmail.com
- Update to version 3.25.1:
  + Fix JSON formatting for Flatpak manifest.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 3.24.3:
  + Fix OpenStreetMap editing in Flatpaks (update librest build
    dependency).
  + Updated translations.
* Tue May  9 2017 zaitor@opensuse.org
- Update to version 3.24.2:
  + Avoid a use-after-free crash in contact store.
  + Updated translations.
* Mon Apr 24 2017 dimstar@opensuse.org
- Update to version 3.24.1:
  + Fix rendering of compacted route labels for transit routing.
  + Don't show the “Next” button when selecting POI types when
    editing OpenStreetMap objects.
  + Use HTTPS Wikipedia links.
  + Updated translations.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Fix running when gnome-online-accounts isn't available.
  + Updated translations.
* Tue Mar 14 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Fix rendering Wikipedia links to articles containing a colon.
  + Updated OpenStreetMap POI definitions for editing.
  + Handle application/geo+json mime type for GeoJSON layer files.
  + Updated translations.
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Support for public transit routing (enabled when service
    definition contains a URL for an OpenTripPlanner server, or by
    debug environment variable).
  + Add a button to reverse a route.
  + Stop using "for in" loops to traverse arrays.
  + Fixes for ES6 (GJS 1.48).
  + Updated translations.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Updated translations.
* Tue Jan 17 2017 zaitor@opensuse.org
- Update to version 3.23.4:
  + Removed usage of deprecated gtk_menu_popup() function.
  + Updated translations.
* Fri Dec 16 2016 sknorr@suse.com
- Improve package description.
* Tue Dec 13 2016 dimstar@opensuse.org
- Update to version 3.23.3:
  + Enable easy building as a flatpak from within GNOME Builder.
  + Updated translations.
* Tue Nov 22 2016 dimstar@opensuse.org
- Update to version 3.23.2:
  + Use Unicode in translatable strings.
  + Updated translations.
* Wed Nov  9 2016 dimstar@opensuse.org
- Update to version 3.23.1:
  + Fixed a typo and a formatting issue.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 3.22.2:
  + Handle a plain 00:00-24:00 opening hour specification as being
    "always open" for POIs.
  + Updated translations.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Mon Sep 12 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Added = accelerator for zoom-in.
  + Fix rendering of website links containing HTML markup
    characters.
  + Updated/added POI definitions for OpenStreetMap editing.
  + Updated translations.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Fix bug where you could not type + or - in the searchbar.
  + Updated translations.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Download a service.json file to get tile server URI among other
    things.
  + Use GtkClutter for the attribution logo, to get transparency.
  + Updated translations.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.21.4:
  + osmEditDialog: URI-escape tel: URIs when copying to the phone
    field.
  + printLayout: Change color of instructionWidget before printing.
  + Updated translations.
- Remove use of sed to fix errounus bump of libchamplain.
* Thu Sep  1 2016 zaitor@opensuse.org
- Update to version 3.20.3.1 (boo#995112):
  + Fix bug where you could not type + or - in the searchbar.
  + Fix horizontal wrapping of the map.
- Use sed to revert libchamplain version bump, upstream did not
  intend to bump.
* Thu Aug 25 2016 badshah400@gmail.com
- Update to version 3.20.3 (boo#995112):
  + Download a service.json file to get tile server URI among
    other things.
  + Use GtkClutter for the attribution logo, to get transparency.
* Sun Jul 31 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Change tile URIs to use Mapbox, through proxy.
  + Fix escaping of tel: URIs.
  + Adapt colors of instuction when printing routes.
  + Updated translations.
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Bump dependencies on libchamplain and gjs.
  + Fix memory leak in osmEdit.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Fix marking of translatable strings.
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Rework geoclue interaction.
  + Ellipsize route instructions in print layout.
  + Add 'aeroway' type to OSM editing.
  + Make auto-complete accent insensitive.
  + Updated translations.
* Tue Mar  1 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Handle case when nothing was found when reverse geocoding
    through context menu.
  + Make sure we validate bounding boxes from geoJSON layer.
  + Add markers to route when printing.
  + Add via points to route when printing.
  + Add ability to add and edit addresses on OpenStreetMap.
  + Allow Maps to shrink more by not using a fixed width for the
    searchbar.
  + Add tooltip to icon next to route entry to help discoverbility
    of drag and drop re-oredering.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Added icon to toggle visibility of a shape layer.
  + Improve travel animations.
  + Add a scale ruler to the bottom left corner.
  + Include less information by default in map bubbles.
  + Add expandable area on map bubbles.
  + Add context menu item for adding location to OpenStreetMap.
  + Enable editting of opening hours on OpenStreetMap.
  + Add internet access tag to map bubbles.
  + Add ele altitude tag to map bubbles.
  + Add website to map bubbles.
  + Add phone nunber to map bubbles.
  + Add support for KML and GPX shape files.
  + Add support for printing a route with instructions.
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Addded a keybinding help overlay (F1 to activate).
  + Fix zoom behaviour to be more aggresive.
  + Fix bug with cancel login in OpenStreetMap account dialog.
  + Add keyboard shortcut for going to current location
    (<Primary>L).
  + Fix layout of OpenStreetMap edit.
  + Fix bug that made it impossible to sign-in to OpenStreetMap if
    you first inputed the wrong credentials.
  + Fix drag-and-drop to be more acceptive and responsive.
  + Make sure we can export our markers to PNG.
  + Give user the choice of exporting markers or not.
  + Add GUI for loading and managing shape layers such as GeoJSON
    or in the future(?) KML.
  + Add roundabout support to route.
  + Use a regular GtkButton for marking favorites.
  + Updated translations.
* Sun Dec 20 2015 zaitor@opensuse.org
- Update to version 3.19.3:
  + Added export to image to context menu.
  + Added support for MultiPoint in GeoJSON.
  + Fixed bug in send-to-dialog when default browser has no icon.
  + Added support for MapBox simplestyle for GeoJSON.
  + Added support for editing locations in OpenStreetMap.
  + Updated translations.
- Add pkgconfig(rest-0.7) and pkgconfig(libxml-0.2) BuildRequires:
  New dependencies.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Fix GeoJSON filling of polygons in polygons.
  + Add simpler keyboard shortcuts for zoom.
  + Fix width of send-to dialog.
  + Add open with browser to send-to dialog that will open a
    location on OpenStreetMap web.
  + Handle the 'geo' URI scheme, this will allow us to handle geu:
    URIs in for instance the browser or in Polari.
  + Go to latest visited view on start up.
  + Updated translations.
- Changes from version 3.19.1:
  + Use new convenience library for GeoClue.
  + Add support for opening and displaying GeoJSON files.
  - https://en.wikipedia.org/wiki/GeoJSON
  - This is with help of the Mapbox geojson-vt javascript code
    found at: https://github.com/mapbox/geojson-vt
  + Updated translations.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Fix bugs in contact address lookup:
  - No more warnings if address has no street address.
  - Do not attempt to classify type of address if only one(1).
  + Make sure the bounding box of a geocoded places is valid before
    using.
  + Make sure send-to-dialog has usable width.
  + Updated translations.
* Sat Oct 10 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fix bugs in zooming to a location or contact.
  + Fix styling of dialog header buttons.
  + Updated translations.
* Fri Sep 25 2015 zaitor@opensuse.org
- Update to version 3.18.0.1:
  + Fix bug that prevented Maps from launching.
  + Updated translations.
* Sun Sep 20 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Add --local switch to use local, offline, tiles from a
    structured directory.
  + Updated translations.
* Sun Aug 30 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Fix memory leaks in contacts handling.
  + Make sure car routes gets correct icon.
  + Updated translations.
* Sat Aug 22 2015 zaitor@opensuse.org
- Update to version 3.17.90.1:
  + Fix up search popup list.
  + Fix storing of transportation type of route.
  + Some bugfixes.
  + Updated translations.
* Sun Aug 16 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Add new user-location icon.
  + Add directional user-location icon.
  + Show heading from Geoclue.
  + Do not animate on 'what is here?'.
  + Add support for Geo URI (RFC5870) in searchbar.
  + Add 'Copy Geo URI' context menu item.
  + Store and complete against recent routes.
  + Updated translations.
* Tue May 12 2015 dimstar@opensuse.org
- Update to version 3.17.1:
  + Switch to template for more UI files.
  + Do not use intltool to translate GSettings schema.
  + Improve height of favorites popover.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Fix favorite popover size.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Provide a symbolic variant of the app icon.
  + Add new appdata screenshots.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Fix links for wikipedia.
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Use proper location instead of nearest city when sending
    location to Weather.
  + Fix bug with layer ordering that made it impossible to drag
    routes under accuracy circle.
  + Fix Clutter/GTK event re-entrant dead-lock on right click.
  + Updated translations.
* Sun Mar  1 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Fix leak in libmaps geocode.
  + Only add contacts that properly geocode to a location.
  + Fix bug that fetched a route twice for each request.
  + Fix event handling of clutter and GTK+ that lead to deadlock
    and freeze when you clicked the map.
  + Fix being able to mark search results as favorites.
  + Updated translations.
- Add pkgconfig(geoclue-2.0) BuildRequires: new dependency.
- Drop gnome-maps-NULL-sentinels.patch: fixed upstream.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90.2:
  + Fix build for clang/FreeBSD.
- Add gnome-maps-NULL-sentinels.patch: Fix missing NULL sentinels.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.15.90.1:
  + Install Maps C library into pkglibdir.
- Changes from version 3.15.90:
  + Show notification with link to privacy panel when location
    service is off.
  + Only show user location marker when location service is
    enabled.
  + Added a 'show-location' activation action, to show contacts in
    Maps.
  + Add contacts with geocodable addresses to the placeStore to
    allow completion in search.
  + Updated translations.
- Add pkgconfig(folks), pkgconfig(gee-0.8),
  pkgconfig(champlain-0.12) and pkgconfig(geocode-glib-1.0)
  BuildRequires: new dependencies.
* Fri Jan 16 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + Smarter filtering in favorites menu.
  + Make opening hours translatable.
  + Convert to "package.js" application convention.
  + Add runtime dependency checks.
  + Refresh place meta data if stale.
  + Switch to new full color mark-location icon.
  + Zoom in and center map marker on double-click.
  + Updated translations.
* Thu Dec 18 2014 zaitor@opensuse.org
- Update to version 3.15.3.1:
  + Use search popover for completion.
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Remove 'I am here' menu item from context menu.
  + Improve geoclue interaction somewhat.
  + Use Overpass API to add meta data to map bubbles.
  + Use HTTPS for GraphHopper service.
  + Add drag-n-drop to route entries.
  + Add check-in possibility to user location bubble
    (Facebook/Foursquare).
  + Updated translations.
* Sun Nov 30 2014 badshah400@gmail.com
- Update to version 3.15.2:
  + Use proper GtkButtons for zoom control.
  + Add a 'No network view' to show when Maps is disconnected.
  + Added <Ctrl-f> accelrator to grab focus on search.
  + Added <Ctrl-d> accelerator to open route planner.
  + Added route button to MapBubble.
  + Enable panning by keyboard.
  + Add extra info to search result bubbles:
  - Popuplation
  - Wikipedia
  - Opening hours
  - Wheelchair accesability.
  + Improve the UI of the search result popover.
  + Add 'share' button to MapBubbles to allow user to
    share location to weather and clocks.
  + Add favorites handling to main window and MapBubbles.
  + Updated translations.
* Tue Nov 11 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Updated translations.
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.1.2:
  + Fix typo in icon name.
- Changes from version 3.14.1.1:
  + Use symbolic icons in instruction list. This fixes scaling
    issues on Hi-DPI and recoloring.
  + Updated translations.
* Fri Oct 10 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Fix issue where icons did not recolor on dark theme.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Add gobject-introspection BuildRequires: enable detection of
  typelib()-Requires (bnc#897852).
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Improve sidebar alignments.
  + Fix default transportation mode bug.
  + Make coordinates in entry editable.
  + Do not forget route on sidebar hide.
  + Hopefully a fix for non-consistent build error.
  + Hopefully a fix for elusive segfault in sidebar.
  + Default focus on entry in sidebar reveal.
  + Fix for theme problem with instruction list.
  + Updated translations.
- Drop gnome-maps-parallelbuild.patch: fixed upstream.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Add high contrast icon of logo.
  + Use kinetic scroll mode.
  + Set correct desktopId for geoclue.
  + Send correct argv/argc to GApplication.
  + Fix bug where selecting from completion nullified placeEntry.
  + Add content rich map markers and map bubbles based on
    GtkPopover.
  + Add tooltips to GtkHeaderButtons.
  + Add support for via points in routing.
  + Updated translations.
* Sun Aug 24 2014 dimstar@opensuse.org
- Add gnome-maps-parallelbuild.patch: Fix rules used to make
  parallel build more reliable (bgo#734507).
* Sat Jul 19 2014 zaitor@opensuse.org
- Update to version 3.13.4:
  + Fix sidebar margin for LTR.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Added sidebar for route searching.
  + Fix styling of popovers.
  + Fix cleanup for make dist.
  + Fixup AppData file.
- Changes from version 3.12.2:
  + New popover based UI for layers menu.
  + Added in app notifications.
  + Make clicking the map grab focus to be able to remove on-screen
    keyboard on tablets.
  + Maps now DBus activatable.
  + Handle GeoClue2 service not available.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Added padding to main window search entry.
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Enable keyboard navigation in search results popover.
  + Make clicking the map grab focus and dismiss on screen
    keyboard.
  + Updated translations.
* Tue Mar  4 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Update about dialog.
  + Fix a bug that could put Maps in an endless loop.
  + Fix a 'make distcheck' bug.
  + Use markup for superscripts.
  + Updated translations.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Make the search results show in a GtkPopover.
  + Fix a bug where search result spinner sometimes wouldn't be
    centered.
  + Updated translations.
* Wed Feb  5 2014 dimstar@opensuse.org
- Update to version 3.11.5.1:
  + Fix some compiler warnings.
* Tue Feb  4 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + Much smoother goto animations.
  + Avoid a redundant zoom-out at end of goto animations by making
    use of new geocode-glib and libchamplain API.
  + Make Maps work against geoclue 2.1.x and latest gtk+.
  + If accuracy area is less than 1, show 'exact' instead of
    '0 km2'.
  + Explicitly specify desired accuracy level to geoclue.
  + Update website URL in AppData file.
  + Make gnome-maps executable a real binary.
  + Update recent added time on re-visits.
  + Fix a compiler warning.
  + Updated translations.
- Add pkgconfig(gobject-introspection-1.0) and pkgcofig(gio-2.0)
  BuildRequires: new dependencies.
* Fri Jan 17 2014 zaitor@opensuse.org
- Update to version 3.11.4.1:
  + Provide completion for search based on recently used search
    results.
* Tue Jan 14 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Set saner minimum zoom level on the map view.
  + Updated translations.
* Thu Nov 21 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Clearer dconf key descriptions.
  + Use Unicode quotation marks and apostrophes.
  + Updated translations.
* Wed Nov 13 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Fix issue of Maps not updating user's location at first launch.
  + Fix the awkward looking and slow goto animation and make it
    linear and fast.
  + Don't point to inexistent directories in gnome-maps script.
  + Mark two forgotten strings for translation.
  + Updated translations.
* Sun Sep 15 2013 dimstar@opensuse.org
- Recommend dbus(org.freedesktop.GeoClue2): having the GeoClue2
  service avaialble allows for geolocation and automatic
  positioning (accuracy depending on available hardware and
  connection).
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Provide an AppData file for GNOME software center.
  + Improved search results popup:
  - Add a scroll window to not fill screen with results.
  - Show place icons when available for user to be able to
    differentiate between results.
  - Show a spinner when search is on going.
  - Show matched part of results in bold fonts.
  + Add a context menu with two options:
  - "What's here?": Finds the name of the place at cursor
    position.
  - "I'm here": Corrects/changes Maps' idea of where user is
    currently.
  + Gracefully handle markup in search results.
  + Fix build against latest gnome-common.
  + Updated translations.
* Fri Aug 23 2013 zaitor@opensuse.org
- Update to version 3.9.90.2:
  + Drop usage of Geoclue library as its going to be dropped in
    Geoclue 1.99.2.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90.1:
  + Brown paperbag release for also updating version in
    configure/build.
- Changes from version 3.9.90:
  + Search results are shown in a popup menu rather than as markers
    on the map.
  + Draw window decorations client-side, following the new GNOME3
    trend.
  + The user location button is no longer a toggle.
  + Add buttons and key bindings for zooming in and out.
  + Updated translations.
* Fri Aug  2 2013 cfarrell@suse.com
- License update: GPL-2.0+: As libgd is compiled with the rest of
  the GPL-2.0+ files, the resulting binary is GPL-2.0+ not
  LGPL-2.1.
* Tue May 14 2013 dimstar@opensuse.org
- Initial package, version 3.9.5.
